﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Web;
using WeiXinPay;
using Newtonsoft.Json;


/// <summary>
/// 根据Code获取OpenID等信息
/// </summary>
public class WxModelAccessToken
{
    public string access_token { get; set; }
    public int expires_in { get; set; }
    public string refresh_token { get; set; }
    public string openid { get; set; }
    public string scope { get; set; }
}
public class WxModelJsapiTicket
{
    public string ticket { get; set; }
    public int expires_in { get; set; }
    public string errmsg { get; set; }
    public int errcode { get; set; }
}
/// <summary>
/// subscribe	用户是否订阅该公众号标识，值为0时，代表此用户没有关注该公众号，拉取不到其余信息。
///openid	用户的标识，对当前公众号唯一
///nickname	用户的昵称
///sex	用户的性别，值为1时是男性，值为2时是女性，值为0时是未知
///city	用户所在城市
///country	用户所在国家
///province	用户所在省份
///language	用户的语言，简体中文为zh_CN
///headimgurl	用户头像，最后一个数值代表正方形头像大小（有0、46、64、96、132数值可选，0代表640*640正方形头像），用户没有头像时该项为空。若用户更换头像，原有头像URL将失效。
///subscribe_time	用户关注时间，为时间戳。如果用户曾多次关注，则取最后关注时间
///unionid	只有在用户将公众号绑定到微信开放平台帐号后，才会出现该字段。详见：获取用户个人信息（UnionID机制）
///remark	公众号运营者对粉丝的备注，公众号运营者可在微信公众平台用户管理界面对粉丝添加备注
///groupid	用户所在的分组ID
///成功实例:
///{
///"subscribe": 1, 
/// "openid": "o6_bmjrPTlm6_2sgVt7hMZOPfL2M", 
/// "nickname": "Band", 
///  "sex": 1, 
///  "language": "zh_CN", 
///  "city": "广州", 
///   "province": "广东", 
///  "country": "中国", 
///  "headimgurl":    "http://wx.qlogo.cn/mmopen/g3MonUZtNHkdmzicIlibx6iaFqAc56vxLSUfpb6n5WKSYVY0ChQKkiaJSgQ1dZuTOgvLLrhJbERQQ4eMsv84eavHiaiceqxibJxCfHe/0", 
/// "subscribe_time": 1382694957,
/// "unionid": " o6_bmasdasdsad6_2sgVt7hMZOPfL"
/// "remark": "",
///  "groupid": 0
///}
/// </summary>
public class WxModelUserInfo
{
    public int subscribe { get; set; }
    public string openid { get; set; }
    public string nickname { get; set; }
    public int sex { get; set; }
    public string language { get; set; }
    public string city { get; set; }
    public string province { get; set; }
    public string country { get; set; }
    public string headimgurl { get; set; }
    public string subscribe_time { get; set; }
    public string unionid { get; set; }
    public string remark { get; set; }
    public int groupid { get; set; }
}
/// <summary>
/// 微信公共处理类 周祥 2015年5月8日 10:37:16
/// </summary>
public class WeiXinCommon
{
    /// <summary>
    /// 获取微信access_token授权
    /// </summary>
    /// <returns></returns>
    public WxModelAccessToken GetAccessToken(string code)
    {
        WxModelAccessToken obj = null;
        string url =
        string.Format(
            "https://api.weixin.qq.com/sns/oauth2/access_token?appid={0}&secret={1}&code={2}&grant_type=authorization_code",
            WxConfig.appid, WxConfig.appsecret, code);
        string returnStr = HttpUtil.Send("", url);
        obj = JsonConvert.DeserializeObject<WxModelAccessToken>(returnStr);
        return obj;
    }
    /// <summary>
    /// 获取用户信息
    /// </summary>
    /// <param name="code"></param>
    /// <returns></returns>
    public WxModelUserInfo GetUserInfo(WxModelAccessToken accessObj)
    {
        //WxModelAccessToken accessObj = GetAccessToken(code);
        // 检查code是否在数据库登陆过
        if (accessObj != null)
        {
            string url =
                string.Format(
                    "https://api.weixin.qq.com/sns/userinfo?access_token={0}&openid={1}&lang=zh_CN",
                    accessObj.access_token, accessObj.openid);
            string returnStr = HttpGet.PageGet(url, null, "text/HTML");
            var obj = JsonConvert.DeserializeObject<WxModelUserInfo>(returnStr);
            return obj;
        }
        return null;
    }
    /// <summary>
    /// 获取微信 Jsapi Ticket 授权
    /// </summary>
    /// <returns></returns>
    public string GetJsapiTicket(string access_token)
    {
        if (HttpContext.Current.Cache.Get("wx_jsapi_ticket_" + access_token) == null)
        {
            string url =
            string.Format(
                "https://api.weixin.qq.com/cgi-bin/ticket/getticket?access_token=" + access_token + "&type=jsapi");
            string returnStr = HttpGet.PageGet(url, null, "text/HTML");
            var obj = JsonConvert.DeserializeObject<WxModelJsapiTicket>(returnStr);
            if (obj.errcode == 0 && obj.errmsg == "ok")
            {
                HttpContext.Current.Cache.Insert("wx_jsapi_ticket_" + access_token, obj.ticket, null, DateTime.Now.AddSeconds(obj.expires_in), System.Web.Caching.Cache.NoSlidingExpiration);
                return obj.ticket;
            }
        }
        return HttpContext.Current.Cache.Get("wx_jsapi_ticket_" + access_token).ToString();
    }
}
