﻿<%@ WebHandler Language="C#" Class="WEBAPI" %>

using System;
using System.Runtime.Remoting.Contexts;
using System.Web;
using System.Web.SessionState;
using System.Xml;
using WeiXinPay;
using Newtonsoft.Json;

public class ActionModel
{
    public string action { get; set; }
    public object json { get; set; }
    public decimal tenpay { get; set; }
    public string shopdesc { get; set; }
    public string sp_billno { get; set; }
}

public class WEBAPI : IHttpHandler, IRequiresSessionState
{
    /// <summary>
    /// web api
    /// </summary>
    /// <param name="context"></param>
    public void ProcessRequest(HttpContext context)
    {
        context.Response.ContentType = "text/plain";
        string json = context.Server.UrlDecode(context.Request.Form.ToString());
        if (json == "")
        {
            json = new System.IO.StreamReader(context.Request.InputStream).ReadLine();
        }
        if (json != "")
        {
            ActionModel model = JsonConvert.DeserializeObject<ActionModel>(json);
            switch (model.action)
            {
                case "GetOpenid":
                    if (context.Session["user_openid"] != null)
                    {
                        object objopenid = new
                        {
                            result = "success",
                            data = context.Session["user_openid"].ToString()
                        };
                        context.Response.Write(JsonConvert.SerializeObject(objopenid));
                    }
                    else
                    {
                        context.Response.Write(JsonConvert.SerializeObject(new
                        {
                            result = "success",
                            data = ""
                        }));
                    }
                    break;
                //获取微信支付参数
                case "wxpayconfig":
                    try
                    {
                        //当前时间 yyyyMMdd
                        string date = DateTime.Now.ToString("yyyyMMdd");
                        decimal tenpay = model.tenpay * 100;
                        string notify_url = "http://ceshi.tecone.net/ashx/pay.ashx";
                        //生成订单10位序列号，此处用时间和随机数生成，商户根据自己调整，保证唯一
                        string sp_billno = model.sp_billno;

                        //创建支付应答对象
                        var packageReqHandler = new RequestHandler(context);
                        //初始化
                        packageReqHandler.init();
                        string timeStamp = TenpayUtil.getTimestamp();
                        string nonceStr = TenpayUtil.getNoncestr();
                        //设置package订单参数
                        packageReqHandler.setParameter("body", model.shopdesc); //商品信息 127字符
                        packageReqHandler.setParameter("appid", WxConfig.appid);
                        packageReqHandler.setParameter("mch_id", WxConfig.mchid);
                        packageReqHandler.setParameter("nonce_str", nonceStr.ToLower());
                        packageReqHandler.setParameter("notify_url", notify_url);
                        packageReqHandler.setParameter("openid", context.Session["user_openid"].ToString());
                        packageReqHandler.setParameter("out_trade_no", sp_billno); //商家订单号
                        packageReqHandler.setParameter("spbill_create_ip", context.Request.UserHostAddress); //用户的公网ip，不是商户服务器IP
                        packageReqHandler.setParameter("total_fee", tenpay.ToString()); //商品金额,以分为单位(money * 100).ToString()
                        packageReqHandler.setParameter("trade_type", "JSAPI");
                        //获取package包
                        string sign = packageReqHandler.CreateMd5Sign("key", WxConfig.appkey);
                        packageReqHandler.setParameter("sign", sign);
                        string data = packageReqHandler.parseXML();
                        //Log.ErrorLog(data);
                        string prepayXml = HttpUtil.Send(data, "https://api.mch.weixin.qq.com/pay/unifiedorder");
                       // Log.ErrorLog(prepayXml);
                        string package = "";
                        //获取预支付ID
                        var xdoc = new XmlDocument();
                        xdoc.LoadXml(prepayXml);
                        XmlNode xn = xdoc.SelectSingleNode("xml");
                        XmlNodeList xnl = xn.ChildNodes;
                        if (xnl.Count > 7)
                        {
                            string prepayId = xnl[7].InnerText;
                            package = string.Format("prepay_id={0}", prepayId);
                        }
                        //设置支付参数
                        var paySignReqHandler = new RequestHandler(context);
                        paySignReqHandler.setParameter("appId", WxConfig.appid);
                        paySignReqHandler.setParameter("timeStamp", timeStamp);
                        paySignReqHandler.setParameter("nonceStr", nonceStr);
                        paySignReqHandler.setParameter("package", package);
                        paySignReqHandler.setParameter("signType", "MD5");
                        string paySign = paySignReqHandler.CreateMd5Sign("key", WxConfig.appkey);
                        object obj = new
                        {
                            appid = WxConfig.appid,
                            timeStamp = timeStamp,
                            nonceStr = nonceStr,
                            package = package,
                            paySign = paySign
                        };
                        object obj2 = new
                        {
                            result = "success",
                            data = obj
                        };
                        //Log.ErrorLog(JsonConvert.SerializeObject(obj2));
                        context.Response.Write(JsonConvert.SerializeObject(obj2));
                    }
                    catch (Exception ex)
                    {
                        Log.ErrorLog(ex.ToString());
                    }
                    break;
                //接口
                default:
                    context.Response.Write(DBAPI.SendDataToAPI(model.action, JsonConvert.SerializeObject(model.json)));
                    break;
            }
        }
    }

    public bool IsReusable
    {
        get
        {
            return false;
        }
    }

}